const inayaFingerprintDevice = (function () {
    async function postScannedImageToInaya(jsonData) {
        try {
            const response = await fetch(inaya_serverUrl + "inayaAPI/fingerprint/device/onScanned", {
                method: "POST",
                headers: {
                    "Content-Type": "application/json; charset=utf-8",
                },
                body: JSON.stringify(jsonData),
            });

            if (response.ok) {
                return {httpStatus: true};
            } else {
                return {httpStatus: false, error: getHttpError(response)};
            }
        } catch (error) {
            return {httpStatus: false, error: getHttpError(error)};
        }
    }

    async function registerDeviceOnInaya(deviceType, ipAddress, scannerId) {
        var device = {
            "deviceType": deviceType,
            "name": scannerId + " at " + ipAddress,
            "ipAddress": ipAddress,
            "scannerId": scannerId,
            "config": {
                "mode": "browser"
            }
        }

        const response = await fetch(inaya_serverUrl + "inayaAPI/fingerprint/device/registerDevice", {
            method: "POST",
            headers: {
                "Content-Type": "application/json; charset=utf-8",
            },
            body: JSON.stringify(device),
        });
    }


    function getHttpError(error) {
        if (error instanceof Response) {
            if (error.status === 0) {
                return 'Service Unavailable';
            } else if (error.status === 404) {
                return 'Requested page not found';
            } else if (error.status === 500) {
                return 'Internal Server Error';
            } else {
                return 'Unhandled Error';
            }
        } else {
            return "Network Error or Unhandled Exception: " + error.message;
        }
    }


    return {
        postScannedImageToInaya: postScannedImageToInaya,
        registerDeviceOnInaya: registerDeviceOnInaya,
    }

}());